@@ -4,4 +4,7 @@ def ip():
     return ip
 def ipv6():
     ip = requests.get("https://6.ipw.cn").text
+    return ip
+def test():
+    ip = requests.get("https://test.ipw.cn").text
     return ip
\ No newline at end of file
